@@ -1,10 +1,9 @@
-include "$KW_LIB_DIR/kwlib.sh"
-include "$KW_LIB_DIR/kwio.sh"
-include "$KW_LIB_DIR/remote.sh"
-include "$KW_LIB_DIR/signal_manager.sh"
+include "${KW_LIB_DIR}/lib/kwlib.sh"
+include "${KW_LIB_DIR}/lib/kwio.sh"
+include "${KW_LIB_DIR}/lib/kw_db.sh"
+include "${KW_LIB_DIR}/lib/remote.sh"
+include "${KW_LIB_DIR}/lib/signal_manager.sh"
 
-declare -gr metadata_dir='metadata'
-declare -gr configs_dir='configs'
 declare -gA options_values
 declare -g root='/'
 declare -g PROC_CONFIG_PATH='/proc/config.gz'
@@ -20,16 +19,19 @@ function kernel_config_manager_main()
   local name_config
   local description_config
   local force
-  local flag='SILENT'
+  local flag
   local optimize
   local user
   local remote
   local ip
   local port
   local env_name
+  local encoded_pwd
+
+  flag=${flag:-'SILENT'}
 
   if [[ -z "$*" ]]; then
-    list_configs
+    list_configs "$flag"
     return "$?"
   fi
 
@@ -44,9 +46,12 @@ function kernel_config_manager_main()
     exit 22 # EINVAL
   fi
 
+  [[ -n "${options_values['VERBOSE']}" ]] && flag='VERBOSE'
+
+  encoded_pwd=$(get_encoded_pwd)
   env_name=$(get_current_env_name)
   if [[ "$?" == 0 ]]; then
-    options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']="${KW_CACHE_DIR}/${ENV_DIR}/${env_name}"
+    options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']="${KW_CACHE_DIR}/${ENV_DIR}/${encoded_pwd}/${env_name}"
   fi
 
   name_config="${options_values['SAVE']}"
@@ -55,22 +60,22 @@ function kernel_config_manager_main()
   optimize="${options_values['OPTIMIZE']}"
 
   if [[ -n "${options_values['SAVE']}" ]]; then
-    save_config_file "$force" "$name_config" "$description_config"
+    save_config_file "$force" "$name_config" "$description_config" "$flag"
     return "$?"
   fi
 
   if [[ -n "${options_values['LIST']}" ]]; then
-    list_configs
+    list_configs "$flag"
     return "$?"
   fi
 
   if [[ -n "${options_values['GET']}" ]]; then
-    get_config "${options_values['GET']}" "$force"
+    get_config "${options_values['GET']}" "$force" "$flag"
     return "$?"
   fi
 
   if [[ -n "${options_values['REMOVE']}" ]]; then
-    remove_config "${options_values['REMOVE']}" "$force"
+    remove_config "${options_values['REMOVE']}" "$force" "$flag"
     return "$?"
   fi
 
@@ -80,70 +85,111 @@ function kernel_config_manager_main()
   fi
 }
 
-# This function handles the save operation of kernel's '.config' file. It
-# checks if the '.config' exists and saves it using git (dir.:
-# <kw_install_path>/configs)
+# This function handles the save operation of kernel's '.config' file. It first
+# checks if the '.config' is registered in the database. If it isn't or if the user
+# wants to overwrite the file, kw saves the '.config' file in 'KW_DATA_DIR/configs'
+# and adds its metadata to the database.
 #
 # @force Force option. If it is set and the current name was already saved,
 #        this option will override the '.config' file under the 'name'
 #        specified by '-n' without any message.
-# @name This option specifies a name for a target .config file. This name
-#       represents the access key for .config.
+# @config_name Name for identifying a target .config file. This name
+#              represents the access key for .config.
 # @description Description for a config file, de descrition from '-d' flag.
+# @flag: Flag to control function output
+#
+# Return:
+# Returns 0 if operation is successful or aborted (no overwrite) and 2 if
+# kw can't find a .config file to save.
 function save_config_file()
 {
   local -r force="$1"
-  local -r name="$2"
-  local -r description="$3"
-  local original_path="$PWD"
-  local -r dot_configs_dir="$KW_DATA_DIR/configs"
+  local -r config_name="$2"
+  local description="$3"
+  local flag="${4:-SILENT}"
+  local kernel_source_tree_path="$PWD"
+  local -r kernel_configs_dir="${KW_DATA_DIR}/configs"
+  local is_on_database=''
+  local datetime
+  local database_columns='("name","description","path","last_updated_datetime")'
+  local -a values=()
+  local rows
+  local cmd
+  local ret
+  declare -A condition_array
 
+  # Get env's kernel source tree
   if [[ -n "${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}" ]]; then
-    original_path="${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}"
+    kernel_source_tree_path="${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}"
   fi
 
-  if [[ ! -f "$original_path/.config" ]]; then
-    complain 'There is no .config file in the current directory'
+  # Checks if there is a kernel config file named '.config' in the target dir
+  if [[ ! -f "${kernel_source_tree_path}/.config" ]]; then
+    complain "There is no kernel config file named '.config' in the directory ${kernel_source_tree_path}"
     return 2 # ENOENT
   fi
 
-  if [[ ! -d "$dot_configs_dir" || ! -d "$dot_configs_dir/$metadata_dir" ]]; then
-    mkdir -p "$dot_configs_dir"
-    cd "$dot_configs_dir" || exit_msg 'It was not possible to move to configs dir'
-    mkdir -p "$metadata_dir" "$configs_dir"
-  fi
+  [[ "$flag" == 'VERBOSE' ]] && flag='CMD_SUBSTITUTION_VERBOSE'
 
-  cd "$dot_configs_dir" || exit_msg 'It was not possible to move to configs dir'
-
-  # Check if the metadata related to .config file already exists
-  if [[ ! -f "$metadata_dir/$name" ]]; then
-    touch "$metadata_dir/$name"
-  elif [[ "$force" != 1 ]]; then
-    if [[ $(ask_yN "$name already exists. Update?") =~ '0' ]]; then
-      complain 'Save operation aborted'
-      cd "$original_path" || exit_msg 'It was not possible to move back from configs dir'
+  # Checks if there is already an entry for that kernel config file in the database
+  condition_array=(['name']="${config_name}")
+  is_on_database="$(select_from 'kernel_config' '' '' 'condition_array' '' "$flag")"
+  if [[ -n "${is_on_database}" && "$force" != 1 ]]; then
+    warning "Kernel config file named '${config_name}' already exists."
+    if [[ $(ask_yN "Do you want to overwrite it?") =~ '0' ]]; then
+      say 'Save operation aborted'
       return 0
     fi
   fi
 
-  if [[ -n "$description" ]]; then
-    printf '%s\n' "$description" > "$metadata_dir/$name"
+  # Create local dir for storing the kernel config files if it doesn't exists
+  if [[ ! -d "${kernel_configs_dir}" ]]; then
+    cmd="mkdir --parents ${kernel_configs_dir}"
+    cmd_manager "$flag" "$cmd"
+    ret="$?"
+    if [[ "$ret" != 0 ]]; then
+      complain 'Could not create kernel configs directory'
+      return "$ret"
+    fi
   fi
 
-  if cmp -s "${original_path}/.config" "${dot_configs_dir}/${configs_dir}/${name}"; then
-    warning "Warning: $name: there's nothing new in this file"
+  cmp --silent "${kernel_source_tree_path}/.config" "${kernel_configs_dir}/${config_name}"
+  if [[ "$?" == 0 && "$force" != 1 ]]; then
+    warning "'${config_name}' kernel config file stored in local filesystem is up to date"
+    if [[ $(ask_yN "Do you want to continue?") =~ '0' ]]; then
+      say 'Save operation aborted'
+      return 0
+    fi
   fi
 
-  cp "$original_path/.config" "$dot_configs_dir/$configs_dir/$name"
+  # Store kernel config file in local filesystem
+  cmd="cp ${kernel_source_tree_path}/.config ${kernel_configs_dir}/${config_name}"
+  cmd_manager "$flag" "$cmd"
+  ret="$?"
+  if [[ "$ret" != 0 ]]; then
+    complain "Couldn't copy ${kernel_source_tree_path}/.config to ${kernel_configs_dir}/${config_name}"
+    return "$ret"
+  fi
+
+  if [[ -z "$description" ]]; then
+    description='NULL'
+  fi
+
+  # Add/Update kernel config entry in local database
+  datetime=$(date '+%Y-%m-%d %H:%M:%S')
+  values=("$config_name" "$description" "${kernel_configs_dir}/${config_name}" "$datetime")
+  rows="$(format_values_db 4 "${values[@]}")"
+  replace_into '"kernel_config"' "$database_columns" "$rows" '' "$flag"
   ret="$?"
 
   if [[ "$ret" -gt 0 ]]; then
-    complain "Could not save user config files"
+    complain "Could not save user kernel config file"
+    if is_safe_path_to_remove "${kernel_configs_dir}/${config_name}"; then
+      cmd_manager "$flag" "rm ${kernel_configs_dir}/${config_name}"
+    fi
   else
-    success "Saved $name"
+    success "Saved kernel config '${config_name}'"
   fi
-
-  cd "$original_path" || exit_msg 'It was not possible to move back from configs dir'
 }
 
 # Clean-up for fetch_config. When running --fetch, some files may be
@@ -157,13 +203,13 @@ function cleanup()
 
   # Setting dotglob to include hidden files when running 'mv'
   shopt -s dotglob
-  if [[ -d "$KW_CACHE_DIR/config" ]]; then
-    cmd_manager "$flag" "mv $KW_CACHE_DIR/config/* $PWD"
-    cmd_manager "$flag" "rmdir $KW_CACHE_DIR/config"
+  if [[ -d "${KW_CACHE_DIR}/config" ]]; then
+    cmd_manager "$flag" "mv ${KW_CACHE_DIR}/config/* ${PWD}"
+    cmd_manager "$flag" "rmdir ${KW_CACHE_DIR}/config"
   fi
 
-  if [[ -f "$KW_CACHE_DIR/lsmod" ]]; then
-    cmd_manager "$flag" "rm $KW_CACHE_DIR/lsmod"
+  if [[ -f "${KW_CACHE_DIR}/lsmod" ]]; then
+    cmd_manager "$flag" "rm ${KW_CACHE_DIR}/lsmod"
   fi
 
   say 'Exiting...'
@@ -176,7 +222,7 @@ function cleanup()
 # For the remote option, this function reads from remote_parameters directly.
 #
 # @flag How to display a command, the default value is "SILENT". For more
-#   options see `src/kwlib.sh` function `cmd_manager`.
+#   options see `src/lib/kwlib.sh` function `cmd_manager`.
 # @output File name to save the config file.
 # @target Target can be 1 (VM_TARGET), 2 (LOCAL_TARGET), and 3 (REMOTE_TARGET)
 #
@@ -188,37 +234,47 @@ function get_config_from_proc()
   local output="$2"
   local target="$3"
   local ret
-  local -r CMD_LOAD_CONFIG_MODULE="modprobe -q configs && [ -s $PROC_CONFIG_PATH ]"
-  local CMD_GET_CONFIG="zcat /proc/config.gz > $output"
+  local -r CMD_LOAD_CONFIG_MODULE="modprobe --quiet configs && [ -s ${PROC_CONFIG_PATH} ]"
+  local CMD_GET_CONFIG="zcat /proc/config.gz > ${output}"
+  local config_base_path="$PWD"
 
-  [[ "$target" == 3 ]] && CMD_GET_CONFIG="zcat /proc/config.gz > /tmp/$output"
+  if [[ -n "${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}" ]]; then
+    config_base_path="${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}"
+  fi
+
+  # If remote, change where the config will be saved
+  [[ "$target" == 3 ]] && CMD_GET_CONFIG="zcat /proc/config.gz > /tmp/${output}"
 
   case "$target" in
     1) # VM
       # We do not support this option with VM
-      return 95
+      return 95 # ENOTSUP
       ;;
     2) # LOCAL
       # Try to find /proc/config, if we cannot find, attempt to load the module
       # and try it again. If we fail, give of of using /proc/config
       if [[ ! -f "$PROC_CONFIG_PATH" ]]; then
-        cmd_manager "$flag" "sudo $CMD_LOAD_CONFIG_MODULE"
-        [[ "$?" != 0 ]] && return 95 # Operation not supported
+        [[ -n "${options_values['VERBOSE']}" ]] && printf '%s\n' "${PROC_CONFIG_PATH} not available. Attempt to load module"
+        cmd_manager "$flag" "sudo ${CMD_LOAD_CONFIG_MODULE}"
+        if [[ "$?" != 0 ]]; then
+          [[ -n "${options_values['VERBOSE']}" ]] && printf '%s\n' "Failed to load configs module."
+          return 95 # Operation not supported
+        fi
       fi
 
       cmd_manager "$flag" "$CMD_GET_CONFIG"
       return 0
       ;;
     3) # REMOTE
-      cmd_remotely "[ -f $PROC_CONFIG_PATH ]" "$flag"
+      cmd_remotely "$flag" "[ -f ${PROC_CONFIG_PATH} ]"
       if [[ "$?" != 0 ]]; then
-        cmd_remotely "$CMD_LOAD_CONFIG_MODULE" "$flag"
+        cmd_remotely "$flag" "$CMD_LOAD_CONFIG_MODULE"
         [[ "$?" != 0 ]] && return 95 # Operation not supported
       fi
 
-      cmd_remotely "$CMD_GET_CONFIG" "$flag"
+      cmd_remotely "$flag" "$CMD_GET_CONFIG"
       [[ "$?" != 0 ]] && return 95 # Operation not supported
-      remote2host "$flag" "/tmp/$output" "$PWD"
+      remote2host "$flag" "/tmp/${output}" "$config_base_path"
       return 0
       ;;
   esac
@@ -230,7 +286,7 @@ function get_config_from_proc()
 # which will try to retrieve the config file from the standard /boot folder.
 #
 # @flag How to display a command, the default value is "SILENT". For more
-#   options see `src/kwlib.sh` function `cmd_manager`.
+#   options see `src/lib/kwlib.sh` function `cmd_manager`.
 # @output File name to save the config file.
 # @target Target can be 1 (VM_TARGET), 2 (LOCAL_TARGET), and 3 (REMOTE_TARGET)
 #
@@ -246,24 +302,33 @@ function get_config_from_boot()
   local ip="${remote_parameters['REMOTE_IP']}"
   local port="${remote_parameters['REMOTE_PORT']}"
   local cmd
+  local config_base_path="$PWD"
+
+  if [[ -n "${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}" ]]; then
+    config_base_path="${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}"
+  fi
 
   case "$target" in
-    1) # VM
-      # TODO: We can support VM in this scenario
-      return 95 # We do not support this option with VM
+    1) # VM, We do not support this option with VM
+      return 95
       ;;
     2) # LOCAL
-      cmd="cp ${root}boot/config-$(uname -r) $output 2>/dev/null"
+      cmd="cp ${root}boot/config-$(uname --kernel-release) ${output} 2>/dev/null"
       cmd_manager "$flag" "$cmd"
       [[ "$?" != 0 ]] && return 95 # ENOTSUP
       return 0
       ;;
     3) # REMOTE
-      kernel_release=$(cmd_remotely 'uname -r' "$flag")
-      cmd_remotely "[ -f ${root}boot/config-$kernel_release ]" "$flag"
+      cmd='uname --kernel-release'
+      [[ -n "${options_values['VERBOSE']}" ]] && printf '%s\n' "$cmd"
+      kernel_release=$(cmd_remotely 'SILENT' "$cmd")
+
+      [[ "$flag" == 'TEST_MODE' ]] && kernel_release='TEST_MODE'
+
+      cmd_remotely "$flag" "[ -f ${root}boot/config-${kernel_release} ]"
       [[ "$?" != 0 ]] && return 95 # ENOTSUP
 
-      remote2host "$flag" "${root}boot/config-$kernel_release" "$PWD"
+      remote2host "$flag" "${root}boot/config-${kernel_release}" "${config_base_path}/.config"
       return 0
       ;;
   esac
@@ -276,7 +341,7 @@ function get_config_from_boot()
 # the new config file.
 #
 # @flag How to display a command, the default value is "SILENT". For more
-#   options see `src/kwlib.sh` function `cmd_manager`.
+#   options see `src/lib/kwlib.sh` function `cmd_manager`.
 # @output File name to save the config file.
 #
 # Return:
@@ -299,13 +364,13 @@ function get_config_from_defconfig()
   arch=${build_config[arch]:-${configurations[arch]}}
 
   # Build command
-  [[ -n "$arch" ]] && cmd+=" ARCH=$arch"
-  [[ -n "$cross_compile" ]] && cmd+=" CROSS_COMPILE=$cross_compile"
+  [[ -n "$arch" ]] && cmd+=" ARCH=${arch}"
+  [[ -n "$cross_compile" ]] && cmd+=" CROSS_COMPILE=${cross_compile}"
 
   # If the --output option is passed, we don't want to override the current
   # config
-  if [[ -f "$PWD/.config" && "$output" != '.config' ]]; then
-    cmd+=" && mv $PWD/.config $output && mv $KW_CACHE_DIR/config/.config $PWD/.config"
+  if [[ -f "${PWD}/.config" && "$output" != '.config' ]]; then
+    cmd+=" && mv ${PWD}/.config ${output} && mv ${KW_CACHE_DIR}/config/.config ${PWD}/.config"
   fi
 
   cmd_manager "$flag" "$cmd"
@@ -348,6 +413,7 @@ function fetch_config()
   local config_base_path="$PWD"
 
   output=${output:-'.config'}
+  flag=${flag:-'SILENT'}
 
   if [[ -n "${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}" ]]; then
     config_base_path="${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}"
@@ -366,20 +432,29 @@ function fetch_config()
   # Folder to store files in case there's an interruption and we need to return
   # things to the state they were before or in case we need a place to store
   # files temporarily.
-  mkdir -p "$KW_CACHE_DIR/config"
+  cmd='mkdir '
+  [[ "$flag" == 'VERBOSE' ]] && cmd+='--verbose '
+  cmd+="--parents ${KW_CACHE_DIR}/config"
+  cmd_manager "$flag" "$cmd"
 
   if [[ -f "${config_base_path}/${output}" ]]; then
-    if [[ -z "$force" && $(ask_yN "Do you want to overwrite $output in your current directory?") =~ "0" ]]; then
+    if [[ -z "$force" && "$(ask_yN "Do you want to overwrite ${output} in your current directory?")" =~ '0' ]]; then
       warning 'Operation aborted'
       return 125 #ECANCELED
     fi
 
-    cp "${config_base_path}/${output}" "$KW_CACHE_DIR/config"
+    cmd='cp '
+    [[ "$flag" == 'VERBOSE' ]] && cmd+='--verbose '
+    cmd+="${config_base_path}/${output} ${KW_CACHE_DIR}/config"
+    cmd_manager "$flag" "$cmd"
   fi
 
   # If --output is provided, we need to backup the current config file
   if [[ -f "${config_base_path}/.config" && "$output" != '.config' ]]; then
-    cp "${config_base_path}/.config" "${KW_CACHE_DIR}/config"
+    cmd='cp '
+    [[ "$flag" == 'VERBOSE' ]] && cmd+='--verbose '
+    cmd+="${config_base_path}/.config ${KW_CACHE_DIR}/config"
+    cmd_manager "$flag" "$cmd"
   fi
 
   signal_manager 'cleanup' || warning 'Was not able to set signal handler'
@@ -418,11 +493,11 @@ function fetch_config()
         mods=$(cmd_manager "$flag" 'lsmod')
         ;;
       3) # REMOTE
-        mods=$(cmd_remotely 'lsmod' "$flag")
+        mods=$(cmd_remotely "$flag" 'lsmod')
         ;;
     esac
 
-    printf "%s" "$mods" > "$KW_CACHE_DIR/lsmod"
+    printf '%s' "$mods" > "${KW_CACHE_DIR}/lsmod"
 
     cmd="make localmodconfig LSMOD=${KW_CACHE_DIR}/lsmod${output_kbuild_flag}"
 
@@ -434,7 +509,7 @@ function fetch_config()
     # .config, run 'make localmodconfig', then move things back to place.
     if [[ "$output" != '.config' ]]; then
       if [[ -f "${config_base_path}/.config" ]]; then
-        cmd_manager "$flag" "mv ${config_base_path}/$output ${config_base_path}/.config"
+        cmd_manager "$flag" "mv ${config_base_path}/${output} ${config_base_path}/.config"
         cmd_manager "$flag" "$cmd"
         cmd_manager "$flag" "mv ${config_base_path}/.config ${config_base_path}/${output}"
         cmd_manager "$flag" "mv ${KW_CACHE_DIR}/config/.config ${config_base_path}/.config"
@@ -447,61 +522,87 @@ function fetch_config()
       cmd_manager "$flag" "$cmd"
     fi
 
-    rm -f "$KW_CACHE_DIR/lsmod"
+    cmd="rm -f ${KW_CACHE_DIR}/lsmod"
+    cmd_manager "$flag" "$cmd"
   fi
 
-  rm -rf "$KW_CACHE_DIR/config"
+  cmd="rm -rf ${KW_CACHE_DIR}/config"
+  cmd_manager "$flag" "$cmd"
   success 'Successfully retrieved' "$output"
 }
 
+# List name, description and last updated datetime of all kernel config files
+# managed by kw.
 function list_configs()
 {
-  local -r dot_configs_dir="$KW_DATA_DIR/configs"
-  local name
-  local content
+  local flag="${1:-SILENT}"
+  local configs
 
-  if [[ ! -d "$dot_configs_dir" || ! -d "$dot_configs_dir/$metadata_dir" ]]; then
-    say 'There is no tracked .config file'
+  [[ "$flag" == 'VERBOSE' ]] && flag='CMD_SUBSTITUTION_VERBOSE'
+
+  configs="$(select_from 'kernel_config' 'name AS \"Name\", description AS \"Description\", last_updated_datetime AS \"Last updated\"' '.mode column' '' '' "$flag")"
+
+  if [[ -z "$configs" ]]; then
+    say 'There are no .config files managed by kw'
     return 0
   fi
 
-  printf '%-30s | %-30s\n' 'Name' $'Description\n'
-  for filename in "$dot_configs_dir/$metadata_dir"/*; do
-    [[ ! -f "$filename" ]] && continue
-    name=$(basename "$filename")
-    content=$(< "$filename")
-    printf '%-30s | %-30s\n' "$name" "$content"
-  done
+  say 'List of .config files managed by kw'
+  printf '%s\n' "$configs"
 }
 
 # Remove and Get operation in the kernel-config-manager has similar criteria for working,
 # because of this, basic_config_validations centralize the basic requirement
 # validation.
 #
-# @target File name of the target config file
+# @config_name Name that identifies .config
 # @force Force option. If set, it will ignores the warning message.
 # @operation You can specify the operation name here
 # @message Customized message to be showed to the users
+# @flag: Flag to control function output
 #
 # Returns:
-# Return 0 if everything ends well, otherwise return an errno code.
+# Exits with 0 if everything ends well, otherwise exits an errno code.
+# TODO: Best to return and let the caller handle it
 function basic_config_validations()
 {
-  local target="$1"
+  local config_name="$1"
   local force="$2"
-  local operation="$3" && shift 3
-  local message="$*"
-  local -r dot_configs_dir="$KW_DATA_DIR/configs/configs"
+  local operation="$3"
+  local message="$4"
+  local flag="${5:-SILENT}"
+  local query_output
+  local -r kernel_configs_dir="${KW_DATA_DIR}/configs"
+  declare -A condition_array
 
-  if [[ ! -f "$dot_configs_dir/$target" ]]; then
-    complain "No such file or directory: $target"
+  if [[ ! -f "${kernel_configs_dir}/${config_name}" ]]; then
+    complain "Couldn't find config file named: ${config_name}"
+    exit 2 # ENOENT
+  fi
+
+  [[ "$flag" == 'VERBOSE' ]] && flag='CMD_SUBSTITUTION_VERBOSE'
+
+  condition_array=(['name']="${config_name}")
+  query_output="$(select_from 'kernel_config' '' '' 'condition_array' '' "$flag")"
+
+  if [[ -z "${query_output}" ]]; then
+    complain "Couldn't find config in database named: ${config_name}"
+    # Ask user what to do with hanging local .config
+    if [[ $(ask_yN "Remove file ${kernel_configs_dir}/${config_name}?") =~ '1' ]]; then
+      if is_safe_path_to_remove "${kernel_configs_dir}/${config_name}"; then
+        say "Removing file: ${kernel_configs_dir}/${config_name}"
+        cmd_manager "$flag" "rm ${kernel_configs_dir}/${config_name}"
+      fi
+    else
+      say "${kernel_configs_dir}/${config_name} not removed"
+    fi
     exit 2 # ENOENT
   fi
 
   if [[ "$force" != 1 ]]; then
     warning "$message"
     if [[ $(ask_yN 'Are you sure that you want to proceed?') =~ '0' ]]; then
-      complain "$operation operation aborted"
+      say "${operation} operation aborted"
       exit 0
     fi
   fi
@@ -512,7 +613,7 @@ function basic_config_validations()
 # will override the existing .config file; because of this, it has a warning
 # message.
 #
-# @target File name of the target config file
+# @config_name Name that identifies .config
 # @force Force option. If it is set and the current name was already saved,
 #        this option will override the '.config' file under the 'name'
 #        specified by '-n' without any message.
@@ -521,13 +622,16 @@ function basic_config_validations()
 # Exit with 0 if everything ends well, otherwise exit an errno code.
 function get_config()
 {
-  local target="$1"
+  local config_name="$1"
   local force="$2"
-  local -r dot_configs_dir="${KW_DATA_DIR}/configs/configs"
+  local flag="$3"
+  local -r kernel_configs_dir="${KW_DATA_DIR}/configs"
   local -r msg='This operation will override the current .config file'
   local config_base_path="$PWD"
+  local cmd
 
   force=${force:-0}
+  flag=${flag:-'SILENT'}
 
   if [[ -n "${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}" ]]; then
     config_base_path="${options_values['ENV_PATH_KBUILD_OUTPUT_FLAG']}"
@@ -536,48 +640,45 @@ function get_config()
   # If we does not have a local config, there's no reason to warn the user
   [[ ! -f "${config_base_path}/.config" ]] && force=1
 
-  basic_config_validations "$target" "$force" 'Get' "$msg"
+  basic_config_validations "$config_name" "$force" 'Get' "$msg" "$flag"
 
-  cp "${dot_configs_dir}/${target}" "${config_base_path}/.config"
-  say "Current config file updated based on ${target}"
+  cmd="cp ${kernel_configs_dir}/${config_name} ${config_base_path}/.config"
+  cmd_manager "$flag" "$cmd"
+  say "Current config file updated based on ${config_name}"
 }
 
 # Remove a config file under kw management
 #
-# @target File name of the target config file
+# @config_name Name that identifies .config
 # @force Force option.
+# @flag: Flag to control function output
 #
 # Returns:
 # Exit 0 if everything ends well, otherwise exit an errno code.
 function remove_config()
 {
-  local target="$1"
+  local config_name="$1"
   local force="$2"
-  local original_path="$PWD"
-  local -r dot_configs_dir="$KW_DATA_DIR/configs"
-  local -r msg="This operation will remove $target from kw management"
+  local flag="${3:-SILENT}"
+  declare -A condition_array
+  local -r kernel_configs_dir="${KW_DATA_DIR}/configs"
+  local -r msg="This operation will remove ${config_name} from kw management"
   local ret
-  local configs
 
-  basic_config_validations "$target" "$force" 'Remove' "$msg"
+  basic_config_validations "$config_name" "$force" 'Remove' "$msg" "$flag"
 
-  cd "$dot_configs_dir" || exit_msg 'It was not possible to move to configs dir'
-
-  rm "${configs_dir}/${target}" "${dot_configs_dir}/${metadata_dir}/${target}"
-  ret="$?"
-  if [[ "$ret" -ne 0 ]]; then
-    exit_msg 'Could not remove config file'
+  if is_safe_path_to_remove "${kernel_configs_dir}/${config_name}"; then
+    cmd_manager "$flag" "rm ${kernel_configs_dir}/${config_name}"
+    if [[ "$?" -gt 0 ]]; then
+      complain "Could not remove ${kernel_configs_dir}/${config_name}"
+      return 1 # EPERM
+    fi
   fi
-  cd "$original_path" || exit_msg 'It was not possible to move back from configs dir'
 
-  say "The $target config file was removed from kw management"
+  condition_array=(['name']="${config_name}")
+  remove_from 'kernel_config' 'condition_array' '' '' "$flag"
 
-  # Without config file, there's no reason to keep config directory
-  configs=$(ls "${dot_configs_dir}/${configs_dir}")
-  if [[ -z "$configs" ]]; then
-    rm -rf "/tmp/${configs_dir}"
-    mv "$dot_configs_dir" /tmp
-  fi
+  say "The ${config_name} config file was removed from kw management"
 }
 
 # This function parses the options from 'kw kernel-config-manager', and populates the global
@@ -588,7 +689,7 @@ function parse_kernel_config_manager_options()
   local long_options
   local options
 
-  long_options='save:,list,get:,remove:,force,description:,fetch,output:,optimize,remote:'
+  long_options='save:,list,get:,remove:,force,description:,fetch,output:,optimize,remote:,verbose'
   short_options='s:,l,r:,d:,f,o:'
 
   options="$(kw_parse "$short_options" "$long_options" "$@")"
@@ -608,6 +709,7 @@ function parse_kernel_config_manager_options()
   options_values['GET']=''
   options_values['REMOVE']=''
   options_values['TARGET']="$LOCAL_TARGET"
+  options_values['VERBOSE']=''
 
   # Set basic default values
   if [[ -n ${deploy_config[default_deploy_target]} ]]; then
@@ -619,11 +721,11 @@ function parse_kernel_config_manager_options()
 
   populate_remote_info ''
   if [[ "$?" == 22 ]]; then
-    options_values['ERROR']="Invalid remote: $remote"
+    options_values['ERROR']="Invalid remote: ${remote}"
     return 22 # EINVAL
   fi
 
-  eval "set -- $options"
+  eval "set -- ${options}"
   while [[ "$#" -gt 0 ]]; do
     case "$1" in
       --force | -f)
@@ -676,11 +778,15 @@ function parse_kernel_config_manager_options()
         options_values['TARGET']="$REMOTE_TARGET"
         shift 2
         ;;
+      --verbose)
+        options_values['VERBOSE']=1
+        shift
+        ;;
       --)
         shift
         ;;
       *)
-        complain "Invalid option: $1"
+        complain "Invalid option: ${1}"
         exit 22 # EINVAL
         ;;
     esac
@@ -701,7 +807,7 @@ function parse_kernel_config_manager_options()
 function config_manager_help()
 {
   if [[ "$1" == --help ]]; then
-    include "$KW_LIB_DIR/help.sh"
+    include "${KW_LIB_DIR}/help.sh"
     kworkflow_man 'kernel-config-manager'
     return
   fi
@@ -710,7 +816,8 @@ function config_manager_help()
     '  kernel-config-manager (-s | --save) <name> [(-d | --description) <description>] [-f | --force] - Save a config' \
     '  kernel-config-manager (-l | --list) - List config files under kw management' \
     '  kernel-config-manager --get <name> [-f | --force] - Get a config labeled with <name>' \
-    '  kernel-config-manager (-r | --remove) <name> [-f | --force] - Remove config labeled with <name>'
+    '  kernel-config-manager (-r | --remove) <name> [-f | --force] - Remove config labeled with <name>' \
+    '  kernel-config-manager (--verbose) - Show a detailed output'
 }
 
 load_build_config
