@@ -16,6 +16,7 @@ declare -ag required_packages=(
   'xz'
   'lzop'
   'zstd'
+  'jq'
 )
 
 # Fedora package manager command
@@ -46,14 +47,14 @@ function generate_fedora_temporary_root_file_system()
   # We do not support initramfs outside grub scope
   [[ "$bootloader_type" != 'GRUB' ]] && return
 
-  cmd+=" $name"
+  cmd+=" ${name}"
 
   if [[ "$target" == 'local' ]]; then
-    cmd_prefix="sudo -E"
+    cmd_prefix="sudo --preserve-env"
   fi
 
-  cmd_manager "$flag" "$cmd_prefix grub2-editenv - unset menu_auto_hide"
-  cmd_manager "$flag" "$cmd_prefix sed -i -e '$grub_regex' /etc/default/grub"
+  cmd_manager "$flag" "${cmd_prefix} grub2-editenv - unset menu_auto_hide"
+  cmd_manager "$flag" "${cmd_prefix} sed --in-place --expression='${grub_regex}' /etc/default/grub"
 
   # Update initramfs
   cmd_manager "$flag" "$cmd_prefix $cmd"
